@@ -1,3 +1,5 @@
+use imgur_openapi::apis::configuration::ApiKey;
+
 mod delete_image;
 mod favorite_image;
 mod generate_access_token;
@@ -19,3 +21,11 @@ pub use get_image::*;
 pub use list_account_images::*;
 pub use update_image::*;
 pub use upload_image::*;
+
+// Convert optional client_id into imgur_api compatible format.
+fn map_to_api_key(client_id: Option<String>) -> Option<ApiKey> {
+    client_id.map(|value| ApiKey {
+        prefix: None,
+        key: format!("Client-ID {value}", value = value),
+    })
+}
